# Integrations

## Test runners/build tools

The Launchable CLI includes pre-built integrations with the following test runners/build tools:

* [Android Debug Bridge (adb)](adb.md)
* [Ant](ant.md)
* [Bazel](bazel.md)
* [Behave](behave.md)
* [CTest](ctest.md)
* [cucumber](cucumber.md)
* [Cypress](cypress.md)
* [GoogleTest](googletest.md)
* [Go Test](go-test.md)
* [Gradle](gradle.md)
* [Jest](jest.md)
* [Maven](maven.md)
* [minitest](minitest.md)
* [nose](nose.md)
* [Nunit](nunit.md)
* [pytest](pytest.md)
* [Robot](robot.md)
* [RSpec](rspec.md)

{% hint style="info" %}
If you're not using any of these, use the [generic 'file-based' runner integration](using-the-generic-file-based-runner-integration.md), the [`raw` profile for custom test runners](raw.md), or [request a plugin](mailto:support@launchableinc.com?subject=Request%20a%20plugin).
{% endhint %}
